@@ -14,7 +14,7 @@
 Manage the invocation of dictionary methods implemented in helper classes.
 
 """
-__docformat__ = "restructuredtext en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
@@ -223,6 +223,9 @@ class DictMethodRunner(object):
             mpL = str(modulePath).split(".")
             moduleName = mpL[-1]
             #
+            # Add the internal dictionaryApi object instance as a kw option
+            #
+            kwargs["dictionaryApi"] = self.__dApi
             mObj = getattr(aMod, moduleName)(**kwargs)
             self.__moduleCache[modulePath] = mObj
 
