@@ -17,7 +17,7 @@ import sys
 from mmcif.api.DataCategory import DataCategory
 from mmcif.api.DictionaryApi import DictionaryApi
 
-__docformat__ = "restructuredtext en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "john.westbrook@rcsb.org"
 __license__ = "Apache 2.0"
