@@ -39,7 +39,7 @@ from mmcif.api.PdbxContainers import DataContainer
 from mmcif.io.IoAdapterBase import IoAdapterBase
 from mmcif.io.PdbxExceptions import PdbxError, PdbxSyntaxError
 
-__docformat__ = "restructuredtext en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "john.westbrook@rcsb.org"
 __license__ = "Apache 2.0"
@@ -262,9 +262,7 @@ class IoAdapterCore(IoAdapterBase):
         diagL = []
         try:
             if readDef:
-                cifFileObj = ParseCifSelective(
-                    inputFilePath, readDef, verbose=self._verbose, intCaseSense=0, maxLineLength=maxLineLength, nullValue="?", parseLogFileName=logFilePath
-                )
+                cifFileObj = ParseCifSelective(inputFilePath, readDef, verbose=self._verbose, intCaseSense=0, maxLineLength=maxLineLength, nullValue="?", parseLogFileName=logFilePath)
             else:
                 cifFileObj = ParseCifSimple(inputFilePath, verbose=self._verbose, intCaseSense=0, maxLineLength=maxLineLength, nullValue="?", parseLogFileName=logFilePath)
             #
@@ -296,7 +294,7 @@ class IoAdapterCore(IoAdapterBase):
 
         return containerList, diagL
 
-    def writeFile(self, outputFilePath, containerList=None, maxLineLength=900, enforceAscii=True, lastInOrder=None, selectOrder=None, **kwargs):
+    def writeFile(self, outputFilePath, containerList=None, doubleQuotingFlag=False, maxLineLength=900, enforceAscii=True, lastInOrder=None, selectOrder=None, **kwargs):
         """Write input list of data containers to the specified output file path in mmCIF format.
 
         Args:
@@ -356,6 +354,9 @@ class IoAdapterCore(IoAdapterBase):
                 logger.info("Timing %d container(s) api loaded in %.4f seconds", len(containerL), stepTime1 - startTime)
             if self._debug:
                 self.__dumpBlocks(cF)
+            if doubleQuotingFlag:
+                cF.SetQuoting(cF.eDOUBLE)
+            #
             cF.Write(str(outputFilePath))
             if self._timing:
                 stepTime2 = time.time()
