@@ -34,7 +34,7 @@ from mmcif.api.DataCategory import DataCategory
 from mmcif.api.PdbxContainers import DataContainer, DefinitionContainer
 from mmcif.io.PdbxExceptions import PdbxError, PdbxSyntaxError
 
-__docformat__ = "restructuredtext en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "john.westbrook@rcsb.org"
 __license__ = "Apache 2.0"
